============================
Occiput - Tomographic Vision
============================

Tomographic reconstruction - 3D and 4D PET, SPECT, CT, MRI. 


Installation
============

Linux, MacOsX, Windows
----------------------

There are two ways to install under Linux and MacOsX and Windows: 

1. If you have pip installed: 

pip install occiput

2. Download source files; uncompress; at the command line, cd to the source folder and run: 

python setup.py build install 


Getting started
===============
To get started, install IPython and launch the scripts in the /notebooks folder. 
The PET reconstruction requires a CUDA-compatible GPU - but then it's really fast! 
Thanks to the IPython and Jupyter magic and to support from Amazon AWS, it is also possible to try occiput.io 
from the browser using GPUs in the cloud: http://www.occiput.io/try/


Website
=======

`occiput.io home page <http://www.occiput.io/>`_. 



